/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * SetVocabState返回参数结构体
 */
export interface SetVocabStateResponse {
  /**
   * 热词表ID
   */
  VocabId?: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateCustomization返回参数结构体
 */
export interface CreateCustomizationResponse {
  /**
   * 模型ID
   */
  ModelId: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintDelete请求参数结构体
 */
export interface VoicePrintDeleteRequest {
  /**
   * 说话人id，说话人唯一标识
   */
  VoicePrintId: string
}

/**
 * DescribeAsyncRecognitionTasks请求参数结构体
 */
export type DescribeAsyncRecognitionTasksRequest = null

/**
 * ModifyCustomizationState请求参数结构体
 */
export interface ModifyCustomizationStateRequest {
  /**
   * 自学习模型ID
   */
  ModelId: string
  /**
   * 想要变换的模型状态，-1代表下线，1代表上线
   */
  ToState: number
}

/**
 * GetAsrVocab返回参数结构体
 */
export interface GetAsrVocabResponse {
  /**
   * 热词表名称
   */
  Name?: string
  /**
   * 热词表描述
   */
  Description?: string
  /**
   * 热词表ID
   */
  VocabId?: string
  /**
   * 词权重列表
   */
  WordWeights?: Array<HotWord>
  /**
   * 词表创建时间
   */
  CreateTime?: string
  /**
   * 词表更新时间
   */
  UpdateTime?: string
  /**
   * 热词表状态，1为默认状态即在识别时默认加载该热词表进行识别，0为初始状态
   */
  State?: number
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintEnroll返回参数结构体
 */
export interface VoicePrintEnrollResponse {
  /**
   * 说话人基本数据
   */
  Data?: VoicePrintBaseData
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintUpdate请求参数结构体
 */
export interface VoicePrintUpdateRequest {
  /**
   * 音频格式 0: pcm, 1: wav
   */
  VoiceFormat: number
  /**
   * 音频采样率 目前仅支持16000 单位Hz
   */
  SampleRate: number
  /**
   * 说话人id， 说话人唯一标识
   */
  VoicePrintId: string
  /**
   * 音频数据, base64 编码, 音频时长不能超过30s，数据大小不超过2M
   */
  Data: string
  /**
   * 说话人昵称  不超过32字节
   */
  SpeakerNick?: string
}

/**
 * CreateAsyncRecognitionTask请求参数结构体
 */
export interface CreateAsyncRecognitionTaskRequest {
  /**
   * 引擎模型类型。
• 16k_zh：中文普通话通用；
• 16k_en：英语；
• 16k_yue：粤语；
• 16k_id：印度尼西亚语；
• 16k_fil：菲律宾语；
• 16k_th：泰语；
• 16k_pt：葡萄牙语；
• 16k_tr：土耳其语；
• 16k_ar：阿拉伯语；
• 16k_es：西班牙语；
   */
  EngineType: string
  /**
   * 语音流地址，支持rtmp、rtsp等流媒体协议，以及各类基于http协议的直播流(不支持hls, m3u8)
   */
  Url: string
  /**
   * 支持HTTP和HTTPS协议，用于接收识别结果，您需要自行搭建公网可调用的服务。回调格式&内容详见：[语音流异步识别回调说明](https://cloud.tencent.com/document/product/1093/52633)
   */
  CallbackUrl: string
  /**
   * 用于生成回调通知中的签名
   */
  SignToken?: string
  /**
   * 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0
   */
  FilterDirty?: number
  /**
   * 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0
   */
  FilterModal?: number
  /**
   * 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认为0
   */
  FilterPunc?: number
  /**
   * 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1
   */
  ConvertNumMode?: number
  /**
   * 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认为0
   */
  WordInfo?: number
  /**
   * 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
   */
  HotwordId?: string
  /**
   * 回调数据中，是否需要对应音频数据。
   */
  AudioData?: boolean
}

/**
 * 热词的词和权重
 */
export interface HotWord {
  /**
   * 热词
注意：此字段可能返回 null，表示取不到有效值。
   */
  Word: string
  /**
   * 权重
注意：此字段可能返回 null，表示取不到有效值。
   */
  Weight: number
}

/**
 * GetAsrVocab请求参数结构体
 */
export interface GetAsrVocabRequest {
  /**
   * 热词表ID
   */
  VocabId: string
}

/**
 * DescribeTaskStatus返回参数结构体
 */
export interface DescribeTaskStatusResponse {
  /**
   * 录音文件识别的请求返回结果。
   */
  Data: TaskStatus
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * SentenceRecognition请求参数结构体
 */
export interface SentenceRecognitionRequest {
  /**
   * 引擎模型类型。
电话场景：
• 8k_zh：中文电话通用；
• 8k_en：英文电话通用；

非电话场景：
• 16k_zh：中文通用；
• 16k_zh-PY：中英粤;
• 16k_zh_medical：中文医疗；
• 16k_en：英语；
• 16k_yue：粤语；
• 16k_ja：日语；
• 16k_ko：韩语；
• 16k_vi：越南语；
• 16k_ms：马来语；
• 16k_id：印度尼西亚语；
• 16k_fil：菲律宾语；
• 16k_th：泰语；
• 16k_pt：葡萄牙语；
• 16k_tr：土耳其语；
• 16k_ar：阿拉伯语；
• 16k_es：西班牙语；
• 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
   */
  EngSerViceType: string
  /**
   * 语音数据来源。0：语音 URL；1：语音数据（post body）。
   */
  SourceType: number
  /**
   * 识别音频的音频格式，支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac、amr。
   */
  VoiceFormat: string
  /**
   * 腾讯云项目 ID，废弃参数，填写0即可。
   * @deprecated
   */
  ProjectId?: number
  /**
   * 子服务类型。2： 一句话识别。
   * @deprecated
   */
  SubServiceType?: number
  /**
   * 语音的URL地址，需要公网环境浏览器可下载。当 SourceType 值为 0时须填写该字段，为 1 时不填。音频时长不能超过60s，音频文件大小不能超过3MB。
   */
  Url?: string
  /**
   * 废弃参数，填写任意字符串即可。
   * @deprecated
   */
  UsrAudioKey?: string
  /**
   * 语音数据，当SourceType 值为1（本地语音数据上传）时必须填写，当SourceType 值为0（语音 URL上传）可不写。要使用base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。音频时长不能超过60s，音频文件大小不能超过3MB（Base64后）。
   */
  Data?: string
  /**
   * 数据长度，单位为字节。当 SourceType 值为1（本地语音数据上传）时必须填写，当 SourceType 值为0（语音 URL上传）可不写（此数据长度为数据未进行base64编码时的数据长度）。
   */
  DataLen?: number
  /**
   * 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认值为 0。
   */
  WordInfo?: number
  /**
   * 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
   */
  FilterDirty?: number
  /**
   * 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
   */
  FilterModal?: number
  /**
   * 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认值为 0。
   */
  FilterPunc?: number
  /**
   * 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1。
   */
  ConvertNumMode?: number
  /**
   * 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
   */
  HotwordId?: string
  /**
   * 自学习模型 id。如设置了该参数，将生效对应的自学习模型。
   */
  CustomizationId?: string
  /**
   * 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
   */
  ReinforceHotword?: number
  /**
   * 临时热词表，该参数用于提升热词识别准确率。
单个热词规则："热词|权重"，不超过30个字符（最多10个汉字），权重1-10；
临时热词表限制：多个热词用英文逗号分割，最多128个热词，参数示例："腾讯云|10,语音识别|5,ASR|10"；
参数 hotword_list 与 hotword_id 区别：
hotword_id：需要先在控制台或接口创建热词表，获得对应hotword_id传入参数来使用热词功能；
hotword_list：每次请求时直接传入临时热词表来使用热词功能，云端不保留临时热词表；
注意：如果同时传入了 hotword_id 和 hotword_list，会优先使用 hotword_list。
   */
  HotwordList?: string
  /**
   * 支持pcm格式的8k音频在与引擎采样率不匹配的情况下升采样到16k后识别，能有效提升识别准确率。仅支持：8000。如：传入 8000 ，则pcm音频采样率为8k，当引擎选用16k_zh， 那么该8k采样率的pcm音频可以在16k_zh引擎下正常识别。 注：此参数仅适用于pcm格式音频，不传入值将维持默认状态，即默认调用的引擎采样率等于pcm音频采样率。
   */
  InputSampleRate?: number
}

/**
 * 说话人验证数据
 */
export interface VoicePrintVerifyData {
  /**
   * 说话人id
注意：此字段可能返回 null，表示取不到有效值。
   */
  VoicePrintId?: string
  /**
   * 匹配度 取值范围(0.0 - 100.0)
注意：此字段可能返回 null，表示取不到有效值。
   */
  Score?: string
  /**
   * 验证结果 0: 未通过 1: 通过
注意：此字段可能返回 null，表示取不到有效值。
   */
  Decision?: number
}

/**
 * CloseAsyncRecognitionTask返回参数结构体
 */
export interface CloseAsyncRecognitionTaskResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 单句的详细识别结果，包含单个词的时间偏移，一般用于生成字幕的场景。
 */
export interface SentenceDetail {
  /**
   * 单句最终识别结果
注意：此字段可能返回 null，表示取不到有效值。
   */
  FinalSentence: string
  /**
   * 单句中间识别结果，使用空格拆分为多个词
注意：此字段可能返回 null，表示取不到有效值。
   */
  SliceSentence: string
  /**
   * 单句开始时间（毫秒）
注意：此字段可能返回 null，表示取不到有效值。
   */
  StartMs: number
  /**
   * 单句结束时间（毫秒）
注意：此字段可能返回 null，表示取不到有效值。
   */
  EndMs: number
  /**
   * 单句中词个数
注意：此字段可能返回 null，表示取不到有效值。
   */
  WordsNum: number
  /**
   * 单句中词详情
注意：此字段可能返回 null，表示取不到有效值。
   */
  Words: Array<SentenceWords>
  /**
   * 单句语速，单位：字数/秒
注意：此字段可能返回 null，表示取不到有效值。
   */
  SpeechSpeed: number
  /**
   * 声道或说话人 Id（请求中如果设置了 speaker_diarization或者ChannelNum为双声道，可区分说话人或声道）
注意：此字段可能返回 null，表示取不到有效值。
   */
  SpeakerId: number
  /**
   * 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。
注意：此字段可能返回 null，表示取不到有效值。
   */
  EmotionalEnergy: number
  /**
   * 本句与上一句之间的静音时长
注意：此字段可能返回 null，表示取不到有效值。
   */
  SilenceTime: number
  /**
   * 情绪类型（可能为空）
注意：此字段可能返回 null，表示取不到有效值。
   */
  EmotionType?: Array<string>
}

/**
 * CreateCustomization请求参数结构体
 */
export interface CreateCustomizationRequest {
  /**
   * 自学习模型名称，需在1-20字符之间
   */
  ModelName: string
  /**
   * 文本文件的下载地址，服务会从该地址下载文件，目前仅支持腾讯云cos
   */
  TextUrl: string
  /**
   * 自学习模型类型，填写8k或者16k
   */
  ModelType: string
  /**
   * 标签信息
   */
  TagInfos?: Array<string>
}

/**
 * DownloadAsrVocab返回参数结构体
 */
export interface DownloadAsrVocabResponse {
  /**
   * 词表ID。
   */
  VocabId?: string
  /**
   * 词表权重文件形式的base64值。
   */
  WordWeightStr?: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateRecTask返回参数结构体
 */
export interface CreateRecTaskResponse {
  /**
   * 录音文件识别的请求返回结果，包含结果查询需要的TaskId
   */
  Data?: Task
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * ModifyCustomization返回参数结构体
 */
export interface ModifyCustomizationResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * GetModelInfo请求参数结构体
 */
export interface GetModelInfoRequest {
  /**
   * 模型id
   */
  ModelId: string
}

/**
 * CreateAsyncRecognitionTask返回参数结构体
 */
export interface CreateAsyncRecognitionTaskResponse {
  /**
   * 请求返回结果，包含本次的任务ID(TaskId)
   */
  Data?: Task
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintDelete返回参数结构体
 */
export interface VoicePrintDeleteResponse {
  /**
   * 说话人基本信息
   */
  Data?: VoicePrintBaseData
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DeleteAsrVocab返回参数结构体
 */
export interface DeleteAsrVocabResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DownloadCustomization返回参数结构体
 */
export interface DownloadCustomizationResponse {
  /**
   * 下载地址
   */
  DownloadUrl?: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateRecTask请求参数结构体
 */
export interface CreateRecTaskRequest {
  /**
   * 引擎模型类型。注意：非电话场景请务必使用16k的引擎。
电话场景：
• 8k_zh：中文电话通用；
• 8k_en：英文电话通用；

非电话场景：
• 16k_zh：中文通用；
• 16k_zh-PY：中英粤;
• 16k_zh_medical：中文医疗；
• 16k_en：英语；
• 16k_yue：粤语；
• 16k_ja：日语；
• 16k_ko：韩语；
• 16k_vi：越南语；
• 16k_ms：马来语；
• 16k_id：印度尼西亚语；
• 16k_fil：菲律宾语；
• 16k_th：泰语；
• 16k_pt：葡萄牙语；
• 16k_tr：土耳其语；
• 16k_ar：阿拉伯语；
• 16k_es：西班牙语；
• 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
   */
  EngineModelType: string
  /**
   * 识别声道数。1：单声道（非电话场景，直接选择单声道即可，忽略音频声道数）；2：双声道（仅支持8k_zh电话场景，双声道应分别对应通话双方）。注意：双声道的电话音频已物理分离说话人，无需再开启说话人分离功能。
   */
  ChannelNum: number
  /**
   * 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点、语速值）；3: 标点符号分段，包含每段时间戳，特别适用于字幕场景（包含词级时间、标点、语速值）。4：【增值付费功能】对识别结果按照语义分段，并展示词级别粒度的详细识别结果，仅支持8k_zh、16k_zh引擎，需购买对应资源包使用（注意：如果账号后付费功能开启并使用此功能，将[自动计费](https://cloud.tencent.com/document/product/1093/35686)）
   */
  ResTextFormat: number
  /**
   * 语音数据来源。0：语音 URL；1：语音数据（post body）。
   */
  SourceType: number
  /**
   * 是否开启说话人分离，0：不开启，1：开启(仅支持8k_zh/16k_zh，ChannelNum=1时可用)，默认值为 0。
注意：8k电话场景建议使用双声道来区分通话双方，设置ChannelNum=2即可，不用开启说话人分离，如果设置了ChannelNum=1，后台会先转码成单声道，说话人分离结果可能产生偏差。
   */
  SpeakerDiarization?: number
  /**
   * 说话人分离人数（需配合开启说话人分离使用），取值范围：0-10，0代表自动分离（目前仅支持≤6个人），1-10代表指定说话人数分离。默认值为 0。
注：此功能结果仅供参考，请根据您的需要谨慎使用。
   */
  SpeakerNumber?: number
  /**
   * 回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。回调格式&内容详见：[录音识别回调说明](https://cloud.tencent.com/document/product/1093/52632)
   */
  CallbackUrl?: string
  /**
   * 语音的URL地址，需要公网环境浏览器可下载。当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
   */
  Url?: string
  /**
   * 语音数据base64编码，当SourceType 值为1时必须填写，为0可不写。音频数据要小于5MB。
   */
  Data?: string
  /**
   * 数据长度，非必填（此数据长度为数据未进行base64编码时的数据长度）。
   */
  DataLen?: number
  /**
   * 是否进行阿拉伯数字智能转换（目前支持中文普通话引擎）。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字，3: 打开数学相关数字转换。默认值为 1。
   */
  ConvertNumMode?: number
  /**
   * 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
   */
  FilterDirty?: number
  /**
   * 热词表id。如不设置该参数，自动生效默认热词表；如设置了该参数，那么将生效对应的热词表。
   */
  HotwordId?: string
  /**
   * 自学习模型 id。如设置了该参数，将生效对应的自学习模型。
   */
  CustomizationId?: string
  /**
   * 附加参数(该参数无意义，忽略即可)
   */
  Extra?: string
  /**
   * 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认值为 0。
   */
  FilterPunc?: number
  /**
   * 是否过滤语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
   */
  FilterModal?: number
  /**
   * 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。0:不开启，1:开启
   */
  EmotionalEnergy?: number
  /**
   * 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
   */
  ReinforceHotword?: number
  /**
   * 单标点最多字数，取值范围：[6，40]。默认为0，不开启该功能。该参数可用于字幕生成场景，控制单行字幕最大字数（设置ResTextFormat为3，解析返回的ResultDetail列表，通过结构中FinalSentence获取单个标点断句结果）。
   */
  SentenceMaxLength?: number
  /**
   * 情绪识别能力(目前支持16k_zh) 默认为0，不开启。 1：开启情绪识别但是不会在文本展示“情绪标签”， 2：开启情绪识别并且在文本展示“情绪标签”。（该功能需要设置ResTextFormat 大于0）
注意：本功能为增值服务，购买对应套餐包后，将参数设置为1或2时方可按对应方式生效，并消耗套餐包对应资源。参数设置为0时无需购买套餐包，也不会消耗对应资源。
   */
  EmotionRecognition?: number
}

/**
 * GetAsrVocabList请求参数结构体
 */
export interface GetAsrVocabListRequest {
  /**
   * 标签信息，格式为“$TagKey : $TagValue ”，中间分隔符为“空格”+“:”+“空格”
   */
  TagInfos?: Array<string>
  /**
   * 分页Offset
   */
  Offset?: number
  /**
   * 分页Limit
   */
  Limit?: number
}

/**
 * GetCustomizationList返回参数结构体
 */
export interface GetCustomizationListResponse {
  /**
   * 自学习模型数组
注意：此字段可能返回 null，表示取不到有效值。
   */
  Data?: Array<Model>
  /**
   * 自学习模型总量
注意：此字段可能返回 null，表示取不到有效值。
   */
  TotalCount?: number
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintVerify请求参数结构体
 */
export interface VoicePrintVerifyRequest {
  /**
   * 音频格式 0: pcm, 1: wav
   */
  VoiceFormat: number
  /**
   * 音频采样率，目前支持16000，单位：Hz，必填
   */
  SampleRate: number
  /**
   * 说话人id, 说话人唯一标识
   */
  VoicePrintId: string
  /**
   * 音频数据, base64 编码, 音频时长不能超过30s，数据大小不超过2M
   */
  Data: string
}

/**
 * DownloadAsrVocab请求参数结构体
 */
export interface DownloadAsrVocabRequest {
  /**
   * 词表ID。
   */
  VocabId: string
}

/**
 * SetVocabState请求参数结构体
 */
export interface SetVocabStateRequest {
  /**
   * 热词表ID。
   */
  VocabId: string
  /**
   * 热词表状态，1：设为默认状态；0：设为非默认状态。
   */
  State: number
}

/**
 * 词表内容
 */
export interface Vocab {
  /**
   * 热词表名称
   */
  Name: string
  /**
   * 热词表描述
   */
  Description: string
  /**
   * 热词表ID
   */
  VocabId: string
  /**
   * 词权重列表
   */
  WordWeights: Array<HotWord>
  /**
   * 词表创建时间
   */
  CreateTime: string
  /**
   * 词表更新时间
   */
  UpdateTime: string
  /**
   * 热词表状态，1为默认状态即在识别时默认加载该热词表进行识别，0为初始状态
   */
  State: number
  /**
   * 标签数组
注意：此字段可能返回 null，表示取不到有效值。
   */
  TagInfos: Array<string>
}

/**
 * CloseAsyncRecognitionTask请求参数结构体
 */
export interface CloseAsyncRecognitionTaskRequest {
  /**
   * 语音流异步识别任务的唯一标识，在创建任务时会返回
   */
  TaskId: number
}

/**
 * 录音文件识别、实时语音异步识别请求的返回数据
 */
export interface Task {
  /**
   * 任务ID，可通过此ID在轮询接口获取识别状态与结果。注意：TaskId数据类型为uint64
   */
  TaskId: number
}

/**
 * 音频流异步识别任务列表
 */
export interface AsyncRecognitionTasks {
  /**
   * 任务列表
注意：此字段可能返回 null，表示取不到有效值。
   */
  Tasks: Array<AsyncRecognitionTaskInfo>
}

/**
 * ModifyCustomization请求参数结构体
 */
export interface ModifyCustomizationRequest {
  /**
   * 要修改的模型ID
   */
  ModelId: string
  /**
   * 要修改的模型名称，长度需在1-20个字符之间
   */
  ModelName?: string
  /**
   * 要修改的模型类型，为8k或者16k
   */
  ModelType?: string
  /**
   * 要修改的模型语料的下载地址，目前仅支持腾讯云cos
   */
  TextUrl?: string
}

/**
 * DeleteCustomization返回参数结构体
 */
export interface DeleteCustomizationResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 获取录音识别结果的返回参数
 */
export interface TaskStatus {
  /**
   * 任务标识。注意：TaskId数据类型为uint64。
   */
  TaskId: number
  /**
   * 任务状态码，0：任务等待，1：任务执行中，2：任务成功，3：任务失败。
   */
  Status: number
  /**
   * 任务状态，waiting：任务等待，doing：任务执行中，success：任务成功，failed：任务失败。
   */
  StatusStr: string
  /**
   * 识别结果。
   */
  Result: string
  /**
   * 失败原因说明。
   */
  ErrorMsg: string
  /**
   * 识别结果详情，包含每个句子中的词时间偏移，一般用于生成字幕的场景。(录音识别请求中ResTextFormat=1时该字段不为空)
注意：此字段可能返回 null，表示取不到有效值。
   */
  ResultDetail: Array<SentenceDetail>
  /**
   * 音频时长(秒)。
注意：此字段可能返回 null，表示取不到有效值。
   */
  AudioDuration: number
}

/**
 * DeleteAsrVocab请求参数结构体
 */
export interface DeleteAsrVocabRequest {
  /**
   * 热词表Id
   */
  VocabId: string
}

/**
 * GetCustomizationList请求参数结构体
 */
export interface GetCustomizationListRequest {
  /**
   * 标签信息，格式为“$TagKey : $TagValue ”，中间分隔符为“空格”+“:”+“空格”
   */
  TagInfos?: Array<string>
  /**
   * 分页大小，默认1000
   */
  Limit?: number
  /**
   * 分页offset，默认0
   */
  Offset?: number
}

/**
 * UpdateAsrVocab返回参数结构体
 */
export interface UpdateAsrVocabResponse {
  /**
   * 热词表ID
   */
  VocabId?: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintEnroll请求参数结构体
 */
export interface VoicePrintEnrollRequest {
  /**
   * 音频格式 0: pcm, 1: wav
   */
  VoiceFormat: number
  /**
   * 音频采样率，目前支持16000，单位：Hz，必填
   */
  SampleRate: number
  /**
   * 音频数据, base64 编码, 音频时长不能超过30s，数据大小不超过2M
   */
  Data: string
  /**
   * 说话人昵称  不超过32字节
   */
  SpeakerNick?: string
}

/**
 * VoicePrintVerify返回参数结构体
 */
export interface VoicePrintVerifyResponse {
  /**
   * 说话人验证数据
   */
  Data?: VoicePrintVerifyData
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateAsrVocab返回参数结构体
 */
export interface CreateAsrVocabResponse {
  /**
   * 词表ID，可用于获取词表信息
   */
  VocabId?: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 自学习模型信息
 */
export interface Model {
  /**
   * 模型名称
   */
  ModelName: string
  /**
   * 模型文件名称
   */
  DictName: string
  /**
   * 模型Id
   */
  ModelId: string
  /**
   * 模型类型，“8k”或者”16k“
   */
  ModelType: string
  /**
   * 服务类型
   */
  ServiceType: string
  /**
   * 模型状态：
-2：模型训练失败；
-1：已下线；
0：训练中；
1：已上线；
3：上线中；
4：下线中；
   */
  ModelState: number
  /**
   * 最后更新时间
   */
  AtUpdated: string
  /**
   * 标签信息
注意：此字段可能返回 null，表示取不到有效值。
   */
  TagInfos: Array<string>
}

/**
 * CreateAsrVocab请求参数结构体
 */
export interface CreateAsrVocabRequest {
  /**
   * 热词表名称，长度在1-255之间
   */
  Name: string
  /**
   * 热词表描述，长度在0-1000之间
   */
  Description?: string
  /**
   * 词权重数组，包含全部的热词和对应的权重。每个热词的长度不大于10个汉字或30个英文字符，权重为[1,10]之间整数，数组长度不大于128
   */
  WordWeights?: Array<HotWord>
  /**
   * 词权重文件（纯文本文件）的二进制base64编码，以行分隔，每行的格式为word|weight，即以英文符号|为分割，左边为词，右边为权重，如：你好|5。
当用户传此参数（参数长度大于0），即以此参数解析词权重，WordWeights会被忽略
   */
  WordWeightStr?: string
}

/**
 * GetModelInfo返回参数结构体
 */
export interface GetModelInfoResponse {
  /**
   * 模型信息
   */
  Data?: Model
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * UpdateAsrVocab请求参数结构体
 */
export interface UpdateAsrVocabRequest {
  /**
   * 热词表ID
   */
  VocabId: string
  /**
   * 热词表名称，长度在1-255之间
   */
  Name?: string
  /**
   * 词权重数组，包含全部的热词和对应的权重。每个热词的长度不大于10，权重为[1,10]之间整数，数组长度不大于128
   */
  WordWeights?: Array<HotWord>
  /**
   * 词权重文件（纯文本文件）的二进制base64编码，以行分隔，每行的格式为word|weight，即以英文符号|为分割，左边为词，右边为权重，如：你好|5。
当用户传此参数（参数长度大于0），即以此参数解析词权重，WordWeights会被忽略
   */
  WordWeightStr?: string
  /**
   * 热词表描述，长度在0-1000之间
   */
  Description?: string
}

/**
 * VoicePrintCount请求参数结构体
 */
export type VoicePrintCountRequest = null

/**
 * DescribeTaskStatus请求参数结构体
 */
export interface DescribeTaskStatusRequest {
  /**
   * 从CreateRecTask接口获取的TaskId，用于获取任务状态与结果。
   */
  TaskId: number
}

/**
 * SentenceRecognition返回参数结构体
 */
export interface SentenceRecognitionResponse {
  /**
   * 识别结果。
   */
  Result?: string
  /**
   * 请求的音频时长，单位为ms
   */
  AudioDuration?: number
  /**
   * 词时间戳列表的长度
注意：此字段可能返回 null，表示取不到有效值。
   */
  WordSize?: number
  /**
   * 词时间戳列表
注意：此字段可能返回 null，表示取不到有效值。
   */
  WordList?: Array<SentenceWord>
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * VoicePrintUpdate返回参数结构体
 */
export interface VoicePrintUpdateResponse {
  /**
   * 说话人基础数据
   */
  Data?: VoicePrintBaseData
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 说话人基础数据，包括说话人id和说话人昵称
 */
export interface VoicePrintBaseData {
  /**
   * 说话人id
注意：此字段可能返回 null，表示取不到有效值。
   */
  VoicePrintId?: string
  /**
   * 说话人昵称
注意：此字段可能返回 null，表示取不到有效值。
   */
  SpeakerNick?: string
}

/**
 * DeleteCustomization请求参数结构体
 */
export interface DeleteCustomizationRequest {
  /**
   * 要删除的模型ID
   */
  ModelId: string
}

/**
 * VoicePrintCount返回参数结构体
 */
export interface VoicePrintCountResponse {
  /**
   * 统计数据
   */
  Data?: VoicePrintCountData
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 音频流异步识别任务信息
 */
export interface AsyncRecognitionTaskInfo {
  /**
   * 任务ID
   */
  TaskId: number
  /**
   * 音频流Url
   */
  Url: string
}

/**
 * ModifyCustomizationState返回参数结构体
 */
export interface ModifyCustomizationStateResponse {
  /**
   * 自学习模型ID
   */
  ModelId?: string
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeAsyncRecognitionTasks返回参数结构体
 */
export interface DescribeAsyncRecognitionTasksResponse {
  /**
   * 任务列表
注意：此字段可能返回 null，表示取不到有效值。
   */
  Data?: AsyncRecognitionTasks
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * GetAsrVocabList返回参数结构体
 */
export interface GetAsrVocabListResponse {
  /**
   * 热词表列表
   */
  VocabList?: Array<Vocab>
  /**
   * 热词列表总数
   */
  TotalCount?: number
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 一句话识别返回的词时间戳
 */
export interface SentenceWord {
  /**
   * 词结果
   */
  Word: string
  /**
   * 词在音频中的开始时间
   */
  StartTime: number
  /**
   * 词在音频中的结束时间
   */
  EndTime: number
}

/**
 * 识别结果中词文本，以及对应时间偏移
 */
export interface SentenceWords {
  /**
   * 词文本
注意：此字段可能返回 null，表示取不到有效值。
   */
  Word: string
  /**
   * 在句子中的开始时间偏移量
注意：此字段可能返回 null，表示取不到有效值。
   */
  OffsetStartMs: number
  /**
   * 在句子中的结束时间偏移量
注意：此字段可能返回 null，表示取不到有效值。
   */
  OffsetEndMs: number
}

/**
 * 统计返回注册数量结构
 */
export interface VoicePrintCountData {
  /**
   * 总数
注意：此字段可能返回 null，表示取不到有效值。
   */
  Total?: number
}

/**
 * DownloadCustomization请求参数结构体
 */
export interface DownloadCustomizationRequest {
  /**
   * 自学习模型ID
   */
  ModelId: string
}
